diff lisp/simple.el @ 5567:3bc58dc9d688

Replace #'flet by #'labels where appropriate, core code. lisp/ChangeLog addition: 2011-09-07 Aidan Kehoe <kehoea@parhasard.net> * simple.el (transpose-subr): * specifier.el (let-specifier): * specifier.el (derive-device-type-from-tag-set): * test-harness.el (batch-test-emacs): * x-compose.el (alias-colon-to-doublequote): * mule/chinese.el (make-chinese-cns11643-charset): * mule/mule-cmds.el (set-locale-for-language-environment): * mule/mule-cmds.el (set-language-environment-coding-systems): * mule/mule-x-init.el (x-use-halfwidth-roman-font): * about.el (about-xemacs): * about.el (about-hackers): * diagnose.el (show-memory-usage): * diagnose.el (show-object-memory-usage-stats): * diagnose.el (show-mc-alloc-memory-usage): * diagnose.el (show-gc-stats): * dialog.el (make-dialog-box): * faces.el: * faces.el (Face-frob-property): * faces.el (set-face-stipple): * glyphs.el: * glyphs.el (init-glyphs): Removed. * help-macro.el (make-help-screen): * info.el (Info-construct-menu): * keymap.el (key-sequence-list-description): * lisp-mode.el (construct-lisp-mode-menu): * loadhist.el (unload-feature): * minibuf.el (get-user-response): * mouse.el (default-mouse-track-check-for-activation): * mouse.el (mouse-track-insert-1): Follow my own advice from the last commit and use #'labels instead of #'flet in core code.
author Aidan Kehoe <kehoea@parhasard.net>
date Wed, 07 Sep 2011 21:21:36 +0100
parents ac37a5f7e5be
children 071b810ceb18
line wrap: on
line diff
--- a/lisp/simple.el	Wed Sep 07 16:26:45 2011 +0100
+++ b/lisp/simple.el	Wed Sep 07 21:21:36 2011 +0100
@@ -2638,21 +2638,21 @@
 
 (defun transpose-subr (mover arg &optional move-region)
   (let (start1 end1 start2 end2)
     ;; XEmacs -- use flet instead of defining a separate function and
     ;; relying on dynamic scope; use (mark t) etc; add code to support
     ;; the new MOVE-REGION arg.
-    (flet ((transpose-subr-1 ()
-	     (if (> (min end1 end2) (max start1 start2))
-		 (error "Don't have two things to transpose"))
-	     (let ((word1 (buffer-substring start1 end1))
-		   (word2 (buffer-substring start2 end2)))
-	       (delete-region start2 end2)
-	       (goto-char start2)
-	       (insert word1)
-	       (goto-char (if (< start1 start2) start1
-			    (+ start1 (- (length word1) (length word2)))))
-	       (delete-char (length word1))
-	       (insert word2))))
+    (labels ((transpose-subr-1 ()
+               (if (> (min end1 end2) (max start1 start2))
+                   (error "Don't have two things to transpose"))
+               (let ((word1 (buffer-substring start1 end1))
+                     (word2 (buffer-substring start2 end2)))
+                 (delete-region start2 end2)
+                 (goto-char start2)
+                 (insert word1)
+                 (goto-char (if (< start1 start2) start1
+                              (+ start1 (- (length word1) (length word2)))))
+                 (delete-char (length word1))
+                 (insert word2))))
       (if (= arg 0)
 	  (progn
 	    (save-excursion
@@ -2638,21 +2638,21 @@
 (defun transpose-subr (mover arg &optional move-region)
   (let (start1 end1 start2 end2)
-    ;; XEmacs -- use flet instead of defining a separate function and
+    ;; XEmacs -- use labels instead of defining a separate function and
     ;; relying on dynamic scope; use (mark t) etc; add code to support
     ;; the new MOVE-REGION arg.